[![Build Status](https://github.com/andgineer/bitwarden-import-msecure/workflows/CI/badge.svg)](https://github.com/andgineer/bitwarden-import-msecure/actions)
[![Coverage](https://raw.githubusercontent.com/andgineer/bitwarden-import-msecure/python-coverage-comment-action-data/badge.svg)](https://htmlpreview.github.io/?https://github.com/andgineer/bitwarden-import-msecure/blob/python-coverage-comment-action-data/htmlcov/index.html)
# bitwarden-import-msecure

Migration from mSecure to Bitwarden.

More flexible than the built-in Bitwarden import tool.

# Documentation

[Bitwarden Import mSecure](https://andgineer.github.io/bitwarden-import-msecure/)

# Developers

Do not forget to run `. ./activate.sh`.

# Scripts
Install [invoke](https://docs.pyinvoke.org/en/stable/) preferably with [pipx](https://pypa.github.io/pipx/):

    pipx install invoke

For a list of available scripts run:

    invoke --list

For more information about a script run:

    invoke <script> --help

## Allure test report

* [Allure report](https://andgineer.github.io/bitwarden-import-msecure/builds/tests/)

## Coverage report
* [Coveralls](https://coveralls.io/github/andgineer/bitwarden-import-msecure)

> Created with cookiecutter using [template](https://github.com/andgineer/cookiecutter-python-package)